@@ -62,6 +62,7 @@
 #endif
 #include "labelregion.hpp"
 #include "value_locate.hpp"
+#include "gdl2gdl.hpp"
 
 using namespace std;
 
@@ -354,8 +355,8 @@ void LibInit()
   const string readKey[]={COMMONKEYWORDSFORSTRINGFORMATTING,"PROMPT"
     ,"KEY_ID","KEY_MATCH","KEY_VALUE" //obsoleted in 5.3
     ,KLISTEND};
-  new DLibPro(lib::read,string("READ"),-1,readKey);
-  new DLibPro(lib::readf,string("READF"),-1,readKey);
+  new DLibPro(lib::read_pro,string("READ"),-1,readKey);
+  new DLibPro(lib::readf_pro,string("READF"),-1,readKey);
 
   const string readsKey[]={COMMONKEYWORDSFORSTRINGFORMATTING,	   KLISTEND}; // no PROMPT
   new DLibPro(lib::reads,string("READS"),-1,readsKey);
@@ -394,7 +395,7 @@ void LibInit()
 
   new DLibFunRetNew(lib::strarr,string("STRARR"),MAXRANK,NULL,NULL,true);
 
-const string ptrArrKey[]={"ALLOCATE_HEAP","NOZERO",KLISTEND};
+  const string ptrArrKey[]={"ALLOCATE_HEAP","NOZERO",KLISTEND};
   new DLibFunRetNew(lib::ptrarr,string("PTRARR"),MAXRANK,ptrArrKey,NULL,true);
   new DLibFunRetNew(lib::objarr,string("OBJARR"),MAXRANK,arrKey,NULL,true);
 
@@ -855,11 +856,11 @@ const string ptrArrKey[]={"ALLOCATE_HEAP","NOZERO",KLISTEND};
       "ZTICK_GET", "YTICK_GET", "XTICK_GET",
       "ZTITLE", "YTITLE", "XTITLE",
       //3D KW
-      "ZVALUE","T3D", "SAVE", "SKIRT", "ZAXIS", "CHANNEL", KLISTEND
+      "ZVALUE","T3D", "SAVE", "SKIRT", "ZAXIS", "CHANNEL",  "SHADES", KLISTEND
     };
   const string shade_surfWarnKey[]=
   {
-       "SHADES", "IMAGE", "PIXELS", KLISTEND //SHADES cannot be correctly made with current plplot code
+      "IMAGE", "PIXELS", KLISTEND 
   };
   new DLibPro(lib::shade_surf,string("SHADE_SURF"),3,shade_surfKey, shade_surfWarnKey);
 
@@ -887,11 +888,11 @@ const string ptrArrKey[]={"ALLOCATE_HEAP","NOZERO",KLISTEND};
      "MAX_VALUE",  "MIN_VALUE", "AX", "AZ", 
      "XLOG", "YLOG", "ZLOG", "XTYPE", "YTYPE", "ZTYPE",      // ([xyz]type undocumented but still existing in SURFACE ...)
      "HORIZONTAL", "LOWER_ONLY", "UPPER_ONLY",  "ZAXIS",  "BOTTOM", 
-     "SKIRT", "SAVE", "T3D",  "ZVALUE", "CHANNEL", KLISTEND
+     "SKIRT", "SAVE", "T3D",  "ZVALUE", "CHANNEL", "SHADES", KLISTEND
     };
   const string surfaceWarnKey[]=
   {
-      "SHADES","LEGO", KLISTEND //SHADES cannot be correctly made with current plplot code
+      "LEGO", KLISTEND 
   };
   new DLibPro(lib::surface,string("SURFACE"),3,surfaceKey, surfaceWarnKey);
 
@@ -1100,5 +1101,20 @@ new DLibPro(lib::pm_pro, string("PM"), -1, pmKey);
   new DLibFunRetNew(lib::shmvar_fun,string("SHMVAR"),9,shmvarKey);
   new DLibFunRetNew(lib::shmdebug_fun,string("SHMDEBUG"),1);
   #endif
+#if !defined(_WIN32) || defined(__CYGWIN__)
+  if (iAmMaster) {
+	new DLibPro(lib::gmem_setvar,string("GMEM_SETVAR"),3);
+	new DLibFunRetNew(lib::gmem_getvar,string("GMEM_GETVAR"),2);
+	new DLibPro(lib::gmem_abort, string("GMEM_ABORT"), 1);
+	new DLibPro(lib::gmem_exit, string("GMEM_EXIT"), 1);
+	new DLibFunRetNew(lib::gmem_fork, string("GMEM_FORK"), 1);
+	const string gmem_sendKey[] = {"NOWAIT", KLISTEND};
+	new DLibPro(lib::gmem_send, string("GMEM_SEND"), 2, gmem_sendKey);
+	const string gmem_statusKey[] = {"ERROR", KLISTEND};
+	new DLibFunRetNew(lib::gmem_status, string("GMEM_STATUS"), 1, gmem_statusKey);
+  }
+  new DLibPro(lib::gmem_subprocess_givevar,string("GMEM_SUBPROCESS_GIVEVAR"),2);
+  new DLibFunRetNew(lib::gmem_subprocess_receivevar,string("GMEM_SUBPROCESS_RECEIVEVAR"),1);
+#endif
 }
 
